define(
//begin v1.x content
{
	"days-standAlone-short": [
		"dom.",
		"seg.",
		"ter.",
		"qua.",
		"qui.",
		"sex.",
		"sáb."
	],
	"field-quarter-relative+-1": "trimestre passado",
	"dateFormatItem-yQQQ": "QQQQ 'de' y",
	"field-day-narrow-relative+0": "hoje",
	"field-day-narrow-relative+1": "amanhã",
	"field-day-short-relative+0": "hoje",
	"field-day-short-relative+1": "amanhã",
	"dateFormatItem-MMMEd": "E, d/MM",
	"field-dayperiod-short": "am/pm",
	"eraNarrow": [
		"a.C.",
		"d.C."
	],
	"dayPeriods-format-narrow-evening1": "noite",
	"days-format-short": [
		"dom.",
		"seg.",
		"ter.",
		"qua.",
		"qui.",
		"sex.",
		"sáb."
	],
	"dayPeriods-format-narrow-morning1": "manhã",
	"dateFormat-long": "d 'de' MMMM 'de' y",
	"dateTimeFormat-medium": "{1}, {0}",
	"dayPeriods-format-wide-pm": "da tarde",
	"dateFormat-full": "EEEE, d 'de' MMMM 'de' y",
	"field-mon-short-relative+-1": "segunda passada",
	"field-day-short-relative+-1": "ontem",
	"dateFormatItem-Md": "dd/MM",
	"dayPeriods-standAlone-wide-pm": "tarde",
	"dayPeriods-format-abbr-am": "a.m.",
	"timeFormat-short": "HH:mm",
	"dayPeriods-standAlone-abbr-am": "a.m.",
	"quarters-format-wide": [
		"1.º trimestre",
		"2.º trimestre",
		"3.º trimestre",
		"4.º trimestre"
	],
	"timeFormat-long": "HH:mm:ss z",
	"dateFormatItem-yMMM": "MM/y",
	"field-day-narrow-relative+-1": "ontem",
	"field-sat-short-relative+-1": "sábado passado",
	"dayPeriods-standAlone-narrow-am": "a.m.",
	"timeFormat-full": "HH:mm:ss zzzz",
	"field-minute-narrow": "min",
	"dateFormatItem-MMMMW": "W.'ª' 'semana' 'de' MMMM",
	"quarters-format-abbr": [
		"1.º trimestre",
		"2.º trimestre",
		"3.º trimestre",
		"4.º trimestre"
	],
	"quarters-standAlone-wide": [
		"1.º trimestre",
		"2.º trimestre",
		"3.º trimestre",
		"4.º trimestre"
	],
	"field-mon-short-relative+0": "esta segunda",
	"field-mon-short-relative+1": "próxima segunda",
	"field-wed-short-relative+-1": "quarta passada",
	"dateFormatItem-yMMMEEEEd": "EEEE, d/MM/y",
	"field-tue-short-relative+0": "esta terça",
	"field-tue-short-relative+1": "próxima terça",
	"field-minute-short": "min",
	"timeFormat-medium": "HH:mm:ss",
	"field-wed-short-relative+0": "esta quarta",
	"field-wed-short-relative+1": "próxima quarta",
	"quarters-standAlone-abbr": [
		"1.º trimestre",
		"2.º trimestre",
		"3.º trimestre",
		"4.º trimestre"
	],
	"dateFormatItem-yw": "w.'ª' 'semana' 'de' Y",
	"eraAbbr": [
		"a.C.",
		"d.C."
	],
	"field-dayperiod": "am/pm",
	"days-standAlone-abbr": [
		"domingo",
		"segunda",
		"terça",
		"quarta",
		"quinta",
		"sexta",
		"sábado"
	],
	"dateTimeFormat-long": "{1} 'às' {0}",
	"dayPeriods-format-narrow-am": "a.m.",
	"dayPeriods-format-narrow-midnight": "meia-noite",
	"dayPeriods-format-narrow-afternoon1": "tarde",
	"dateFormatItem-MMMd": "d/MM",
	"field-quarter-relative+0": "este trimestre",
	"field-dayperiod-narrow": "am/pm",
	"field-quarter-relative+1": "próximo trimestre",
	"field-zone-short": "fuso horário",
	"dateTimeFormat-full": "{1} 'às' {0}",
	"field-second-narrow": "s",
	"field-thu-short-relative+0": "esta quinta",
	"field-thu-short-relative+1": "próxima quinta",
	"dayPeriods-format-abbr-pm": "p.m.",
	"field-quarter-narrow-relative+0": "este trim.",
	"field-quarter-narrow-relative+1": "próximo trim.",
	"days-format-abbr": [
		"domingo",
		"segunda",
		"terça",
		"quarta",
		"quinta",
		"sexta",
		"sábado"
	],
	"dayPeriods-standAlone-abbr-pm": "p.m.",
	"dateFormatItem-yMMMd": "d/MM/y",
	"eraNames": [
		"a.C.",
		"d.C."
	],
	"days-format-narrow": [
		"D",
		"S",
		"T",
		"Q",
		"Q",
		"S",
		"S"
	],
	"field-zone-narrow": "fuso horário",
	"days-standAlone-narrow": [
		"D",
		"S",
		"T",
		"Q",
		"Q",
		"S",
		"S"
	],
	"dayPeriods-standAlone-narrow-pm": "p.m.",
	"field-quarter-short-relative+0": "este trim.",
	"field-quarter-short-relative+1": "próximo trim.",
	"dayPeriods-format-wide-am": "da manhã",
	"dayPeriods-standAlone-wide-am": "manhã",
	"field-fri-short-relative+-1": "sexta passada",
	"dateFormatItem-MMMMEd": "ccc, d 'de' MMMM",
	"field-quarter-short-relative+-1": "trim. passado",
	"dayPeriods-format-narrow-night1": "madrugada",
	"dateFormat-short": "dd/MM/yy",
	"dateFormatItem-yMMMMEd": "ccc, d 'de' MMMM 'de' y",
	"field-second-short": "s",
	"dayPeriods-format-narrow-noon": "meio-dia",
	"field-fri-short-relative+0": "esta sexta",
	"dateFormatItem-yMMMEd": "E, d/MM/y",
	"field-fri-short-relative+1": "próxima sexta",
	"field-quarter-narrow-relative+-1": "trim. passado",
	"field-sat-short-relative+0": "este sábado",
	"dateFormat-medium": "dd/MM/y",
	"field-sat-short-relative+1": "próximo sábado",
	"dayPeriods-format-narrow-pm": "p.m.",
	"dateTimeFormat-short": "{1}, {0}",
	"field-sun-short-relative+-1": "domingo passado",
	"field-thu-short-relative+-1": "quinta passada",
	"field-tue-short-relative+-1": "terça passada",
	"field-sun-short-relative+0": "este domingo",
	"field-sun-short-relative+1": "próximo domingo"
}
//end v1.x content
);